@@ -35,6 +35,7 @@
 
 #include <KCalCore/OccurrenceIterator>
 #include <KCheckableProxyModel>
+#include <KLocalizedString>
 #include <QIcon>
 #include "calendarview_debug.h"
 
@@ -46,9 +47,7 @@
 
 using namespace EventViews;
 
-namespace EventViews
-{
-
+namespace EventViews {
 class MonthViewPrivate : public Akonadi::ETMCalendar::CalendarObserver
 {
     MonthView *q;
@@ -62,12 +61,12 @@ public: /// Methods
     void triggerDelayedReload(EventView::Change reason);
 
 public:  /// Members
-    QTimer                           reloadTimer;
-    MonthScene                      *scene;
-    QDate                            selectedItemDate;
-    Akonadi::Item::Id                selectedItemId;
-    MonthGraphicsView               *view;
-    QToolButton                     *fullView;
+    QTimer reloadTimer;
+    MonthScene *scene = nullptr;
+    QDate selectedItemDate;
+    Akonadi::Item::Id selectedItemId;
+    MonthGraphicsView *view = nullptr;
+    QToolButton *fullView = nullptr;
 
     // List of uids for QDate
     QMap<QDate, QStringList > mBusyDays;
@@ -76,20 +75,20 @@ protected:
     /* reimplemented from KCalCore::Calendar::CalendarObserver */
     void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override;
     void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override;
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) override;
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence,
+                                  const KCalCore::Calendar *calendar) override;
 private:
     //quiet --overloaded-virtual warning
     using KCalCore::Calendar::CalendarObserver::calendarIncidenceDeleted;
 };
-
 }
 
 MonthViewPrivate::MonthViewPrivate(MonthView *qq)
-    : q(qq),
-      scene(new MonthScene(qq)),
-      selectedItemId(-1),
-      view(new MonthGraphicsView(qq)),
-      fullView(nullptr)
+    : q(qq)
+    , scene(new MonthScene(qq))
+    , selectedItemId(-1)
+    , view(new MonthGraphicsView(qq))
+    , fullView(nullptr)
 {
     reloadTimer.setSingleShot(true);
     view->setScene(scene);
@@ -105,8 +104,8 @@ void MonthViewPrivate::addIncidence(const Akonadi::Item &incidence)
 
 void MonthViewPrivate::moveStartDate(int weeks, int months)
 {
-    KDateTime start = q->startDateTime();
-    KDateTime end = q->endDateTime();
+    auto start = q->startDateTime();
+    auto end = q->endDateTime();
     start = start.addDays(weeks * 7);
     end = end.addDays(weeks * 7);
     start = start.addMonths(months);
@@ -149,7 +148,8 @@ void MonthViewPrivate::calendarIncidenceChanged(const KCalCore::Incidence::Ptr &
     triggerDelayedReload(MonthView::IncidencesEdited);
 }
 
-void MonthViewPrivate::calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar)
+void MonthViewPrivate::calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence,
+                                                const KCalCore::Calendar *calendar)
 {
     Q_UNUSED(calendar);
     Q_ASSERT(!incidence->uid().isEmpty());
@@ -159,7 +159,8 @@ void MonthViewPrivate::calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &
 /// MonthView
 
 MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
-    : EventView(parent), d(new MonthViewPrivate(this))
+    : EventView(parent)
+    , d(new MonthViewPrivate(this))
 {
     QHBoxLayout *topLayout = new QHBoxLayout(this);
     topLayout->addWidget(d->view);
@@ -178,11 +179,11 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
         d->fullView->setAutoRaise(true);
         d->fullView->setCheckable(true);
         d->fullView->setChecked(preferences()->fullViewMonth());
-        d->fullView->isChecked() ?
-        d->fullView->setToolTip(i18nc("@info:tooltip",
-                                      "Display calendar in a normal size")) :
-        d->fullView->setToolTip(i18nc("@info:tooltip",
-                                      "Display calendar in a full window"));
+        d->fullView->isChecked()
+        ? d->fullView->setToolTip(i18nc("@info:tooltip",
+                                        "Display calendar in a normal size"))
+        : d->fullView->setToolTip(i18nc("@info:tooltip",
+                                        "Display calendar in a full window"));
         d->fullView->setWhatsThis(
             i18nc("@info:whatsthis",
                   "Click this button and the month view will be enlarged to fill the "
@@ -314,7 +315,7 @@ QDateTime MonthView::selectionEnd() const
     return selectionStart();
 }
 
-void MonthView::setDateRange(const KDateTime &start, const KDateTime &end,
+void MonthView::setDateRange(const QDateTime &start, const QDateTime &end,
                              const QDate &preferredMonth)
 {
     EventView::setDateRange(start, end, preferredMonth);
@@ -373,6 +374,7 @@ void MonthView::wheelEvent(QWheelEvent *event)
     // call accept in every case, we do not want anybody else to react
     event->accept();
 }
+
 #endif
 
 void MonthView::keyPressEvent(QKeyEvent *event)
@@ -446,16 +448,15 @@ void MonthView::showDates(const QDate &start, const QDate &end, const QDate &pre
     d->triggerDelayedReload(DatesChanged);
 }
 
-QPair<KDateTime, KDateTime> MonthView::actualDateRange(const KDateTime &start,
-        const KDateTime &,
-        const QDate &preferredMonth) const
+QPair<QDateTime, QDateTime> MonthView::actualDateRange(const QDateTime &start, const QDateTime &,
+                                                       const QDate &preferredMonth) const
 {
-    KDateTime dayOne = preferredMonth.isValid() ? KDateTime(preferredMonth) : start;
+    QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth) : start;
     dayOne.setDate(QDate(dayOne.date().year(), dayOne.date().month(), 1));
     const int weekdayCol = (dayOne.date().dayOfWeek() + 7 - QLocale().firstDayOfWeek()) % 7;
-    KDateTime actualStart = dayOne.addDays(-weekdayCol);
+    QDateTime actualStart = dayOne.addDays(-weekdayCol);
     actualStart.setTime(QTime(0, 0, 0, 0));
-    KDateTime actualEnd = actualStart.addDays(6 * 7 - 1);
+    QDateTime actualEnd = actualStart.addDays(6 * 7 - 1);
     actualEnd.setTime(QTime(23, 59, 59, 99));
     return qMakePair(actualStart, actualEnd);
 }
@@ -498,13 +499,12 @@ void MonthView::reloadIncidences()
     // build monthcells hash
     int i = 0;
     for (QDate date = actualStartDateTime().date();
-            date <= actualEndDateTime().date(); date = date.addDays(1)) {
+         date <= actualEndDateTime().date(); date = date.addDays(1)) {
         d->scene->mMonthCellMap[ date ] = new MonthCell(i, date, d->scene);
-        i ++;
+        i++;
     }
 
     // build global event list
-    KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
     const bool colorMonthBusyDays = preferences()->colorMonthBusyDays();
 
     KCalCore::OccurrenceIterator occurIter(*calendar(), actualStartDateTime(), actualEndDateTime());
@@ -512,12 +512,12 @@ void MonthView::reloadIncidences()
         occurIter.next();
 
         // Remove the two checks when filtering is done through a proxyModel, when using calendar search
-        if (!preferences()->showTodosMonthView() &&
-                occurIter.incidence()->type() == KCalCore::Incidence::TypeTodo) {
+        if (!preferences()->showTodosMonthView()
+            && occurIter.incidence()->type() == KCalCore::Incidence::TypeTodo) {
             continue;
         }
-        if (!preferences()->showJournalsMonthView() &&
-                occurIter.incidence()->type() == KCalCore::Incidence::TypeJournal) {
+        if (!preferences()->showJournalsMonthView()
+            && occurIter.incidence()->type() == KCalCore::Incidence::TypeJournal) {
             continue;
         }
 
@@ -534,13 +534,13 @@ void MonthView::reloadIncidences()
         Q_ASSERT(item.isValid());
         Q_ASSERT(item.hasPayload());
         MonthItem *manager = new IncidenceMonthItem(d->scene,
-                calendar(),
-                item,
-                occurIter.incidence(),
-                occurIter.occurrenceStartDate().toTimeSpec(timeSpec).date());
+                                                    calendar(),
+                                                    item,
+                                                    occurIter.incidence(),
+                                                    occurIter.occurrenceStartDate().toLocalTime().date());
         d->scene->mManagerList << manager;
-        if (d->selectedItemId == item.id() &&
-                manager->realStartDate() == d->selectedItemDate) {
+        if (d->selectedItemId == item.id()
+            && manager->realStartDate() == d->selectedItemDate) {
             // only select it outside the loop because we are still creating items
             itemToReselect = manager;
         }
@@ -552,16 +552,16 @@ void MonthView::reloadIncidences()
 
     // add holidays
     const QList<QDate> workDays = CalendarSupport::workDays(actualStartDateTime().date(),
-                                  actualEndDateTime().date());
+                                                            actualEndDateTime().date());
 
     for (QDate date = actualStartDateTime().date();
-            date <= actualEndDateTime().date(); date = date.addDays(1)) {
+         date <= actualEndDateTime().date(); date = date.addDays(1)) {
         // Only call CalendarSupport::holiday() if it's not a workDay, saves come cpu cicles.
         if (!workDays.contains(date)) {
             QStringList holidays(CalendarSupport::holiday(date));
             if (!holidays.isEmpty()) {
-                MonthItem *holidayItem =
-                    new HolidayMonthItem(
+                MonthItem *holidayItem
+                    = new HolidayMonthItem(
                     d->scene, date,
                     holidays.join(i18nc("@item:intext delimiter for joining holiday names", ",")));
                 d->scene->mManagerList << holidayItem;
@@ -571,13 +571,13 @@ void MonthView::reloadIncidences()
 
     // sort it
     std::sort(d->scene->mManagerList.begin(),
-          d->scene->mManagerList.end(),
-          MonthItem::greaterThan);
+              d->scene->mManagerList.end(),
+              MonthItem::greaterThan);
 
     // build each month's cell event list
     foreach (MonthItem *manager, d->scene->mManagerList) {
         for (QDate date = manager->startDate();
-                date <= manager->endDate(); date = date.addDays(1)) {
+             date <= manager->endDate(); date = date.addDays(1)) {
             MonthCell *cell = d->scene->mMonthCellMap.value(date);
             if (cell) {
                 cell->mMonthItemList << manager;
@@ -608,7 +608,7 @@ void MonthView::calendarReset()
 QDate MonthView::averageDate() const
 {
     return actualStartDateTime().date().addDays(
-               actualStartDateTime().date().daysTo(actualEndDateTime().date()) / 2);
+        actualStartDateTime().date().daysTo(actualEndDateTime().date()) / 2);
 }
 
 int MonthView::currentMonth() const
